# Dataverk 

Kodebasert serverless ETL på NAIS med tilgangsstyring i Vault.

Docs: https://dataverk.readthedocs.io/en/latest/


## Relaterte  prosjekter

url | beskrivelse
----| -----------
[go-jek feast](https://github.com/gojek/feast/) | Feast - Feature Store for Machine Learning
[ContinuumIO/intake](https://github.com/ContinuumIO/intake/) | Intake: A general interface for loading data
[frictionlessdata.io](https://frictionlessdata.io/) | Frictionless data
[git lfs](https://git-lfs.github.com/) | Github Large File Storage
[dvc.org](https://dvc.org) | Data Science Version Control 
[quilt (github)](https://github.com/quiltdata) | Quilt - Version and deploy data
[Python package in S3](https://github.com/novemberfiveco/s3pypi) | CLI tool for creating a Python Package Repo i S3
[pypiserver based on bottle](https://github.com/pypiserver/pypiserver) | Minimal PyPI server
